logging

package
v0.0.0-...-6582c30 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 16, 2017 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package logging provides a simple logger interface

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Logger

type Logger interface {
	Debug(v ...interface{})
	Info(v ...interface{})
	Warning(v ...interface{})
	Error(v ...interface{})
	Critical(v ...interface{})
	Fatal(v ...interface{})
}

Logger collects logging information at several levels

Source Files

  • log.go

Directories

Path Synopsis
Package gologging provides a logger implementation based on the github.com/op/go-logging pkg
Package gologging provides a logger implementation based on the github.com/op/go-logging pkg

Jump to