gologging

package
v0.0.0-...-6582c30 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 16, 2017 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package gologging provides a logger implementation based on the github.com/op/go-logging pkg

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewLogger

func NewLogger(level string, out io.Writer, prefix string) (logging.Logger, error)

NewLogger returns a krakend logger wrapping a gologging logger

Types

type Logger

type Logger struct {
	Logger *gologging.Logger
}

Logger is a wrapper over a github.com/op/go-logging logger

func (Logger) Critical

func (l Logger) Critical(v ...interface{})

Critical implements the logger interface

func (Logger) Debug

func (l Logger) Debug(v ...interface{})

Debug implements the logger interface

func (Logger) Error

func (l Logger) Error(v ...interface{})

Error implements the logger interface

func (Logger) Fatal

func (l Logger) Fatal(v ...interface{})

Fatal implements the logger interface

func (Logger) Info

func (l Logger) Info(v ...interface{})

Info implements the logger interface

func (Logger) Warning

func (l Logger) Warning(v ...interface{})

Warning implements the logger interface

Source Files

  • log.go

Jump to