Documentation
¶
Index ¶
- func DefaultConfig(pf proxy.Factory, logger logging.Logger, middlewares []negroni.Handler) mux.Config
- func DefaultConfigWithRouter(pf proxy.Factory, logger logging.Logger, muxEngine *gorilla.Router, ...) mux.Config
- func DefaultFactory(pf proxy.Factory, logger logging.Logger, middlewares []negroni.Handler) router.Factory
- func NewGorillaRouter() *gorilla.Router
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultConfig ¶
func DefaultConfig(pf proxy.Factory, logger logging.Logger, middlewares []negroni.Handler) mux.Config
DefaultConfig returns the struct that collects the parts the router should be builded from
func DefaultConfigWithRouter ¶
func DefaultConfigWithRouter(pf proxy.Factory, logger logging.Logger, muxEngine *gorilla.Router, middlewares []negroni.Handler) mux.Config
DefaultConfigWithRouter returns the struct that collects the parts the router should be builded from with the injected gorilla mux router
Types ¶
This section is empty.
Source Files
¶
- router.go
Click to show internal directories.
Click to hide internal directories.