package
Version:
v0.0.0-...-6582c30
Opens a new window with list of versions in this module.
Published: Aug 16, 2017
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package gologging provides a logger implementation based on the github.com/op/go-logging pkg
NewLogger returns a krakend logger wrapping a gologging logger
Logger is a wrapper over a github.com/op/go-logging logger
func (l Logger) Critical(v ...interface{})
Critical implements the logger interface
func (l Logger) Debug(v ...interface{})
Debug implements the logger interface
func (l Logger) Error(v ...interface{})
Error implements the logger interface
func (l Logger) Fatal(v ...interface{})
Fatal implements the logger interface
func (l Logger) Info(v ...interface{})
Info implements the logger interface
func (l Logger) Warning(v ...interface{})
Warning implements the logger interface
Source Files
¶
Click to show internal directories.
Click to hide internal directories.